angular.module('beamng.apps').directive('basicFull', ['StreamsManager', 'UiUnits', function (StreamsManager, UiUnits) {
    return {
		template:
			'<object style="width:100%; height:100%; pointer-events: none" type="image/svg+xml" data="modules/apps/BasicFull/basic-full.svg?t=' + Date.now() + '"/>',
		replace: true,
		link: function (scope, element, attrs) {
			StreamsManager.add(['electrics', 'engineInfo']);
	
			scope.$on('$destroy', function () {
				StreamsManager.remove(['electrics', 'engineInfo']);
			});
		
			element.on('load', function () {
				var svg    = element[0].contentDocument
				, barRight = svg.getElementById('bar-right')
				, barLeft  = svg.getElementById('bar-left')
				, stfactor = 200
				, speed  = svg.getElementById('txt0')
				, rev   	= svg.getElementById('txt1')
				, gear 	= svg.getElementById('txt2')
				, unused    = svg.getElementById('txt3')
				, gearNames = ['P', 'R', 'N', 'D', '2', '1']
				, lgear = ''
				, bgear = ''
				, parking  = svg.getElementById('bar0')
				, clutch   = svg.getElementById('bar1')
				, throttle = svg.getElementById('bar2')
				, brake    = svg.getElementById('bar3')
				, pfactor = 100
				;
		
				scope.$on('VehicleReset', function () {
					lgear = ' - ';
				});
		
				scope.$on('streamsUpdate', function (event, streams) {
					if (streams.engineInfo != null){
					
						if (streams.engineInfo[13] == 'manual') {
							var mGear = streams.electrics.gear
							, maxFGears = streams.engineInfo[6]
							, maxRGears = streams.engineInfo[7]
							, sign = mGear ? (mGear < 0 ? -1 : 1) : 0
							;
					
							if (sign == -1) bGear = 'R';
							else if (sign == 1) bGear = 'F';
					
							if (mGear > 0) lGear = Math.abs(mGear) + '/' + maxFGears;
							else if (mGear < 0 && maxRGears > 1) lGear = Math.abs(mGear) + '/' + maxRGears;
							else if (mGear == 0) {
								lGear = '';
								bGear = 'N'
							}
						} else {
							lGear = '';
							bGear = gearNames[Math.round(streams.electrics.gear_A * 5)];
						}
					
						speed.innerHTML = UiUnits.speed(streams.electrics.wheelspeed).val.toFixed().slice(-4) + ' km/h';
						rev.innerHTML = Math.round(streams.engineInfo[4]).toString().slice(-4) + ' RPM';
						gear.innerHTML = bGear + ' ' + lGear;
						unused.innerHTML = '';
					
					}
					if(streams.electrics != null){
						
						var steeringRaw = streams.electrics.steering_input;
						
						if (steeringRaw > 0) {
							barRight.setAttribute('width', steeringRaw * 200);
							barLeft.setAttribute('width', 0)
						} else {
							barRight.setAttribute('width', 0)
							barLeft.setAttribute('width', -steeringRaw * 200);
						}
					
						clutch.setAttribute('width', streams.electrics.clutch * 100);
						brake.setAttribute('width',    streams.electrics.brake * 100);
						throttle.setAttribute('width', streams.electrics.throttle * 100);
						parking.setAttribute('width',  streams.electrics.parkingbrake * 100);
					}
				});
			});
		}
	}
}]);